Netdev List
 help / color / mirror / Atom feed
From: Thomas Gleixner <tglx@kernel.org>
To: LKML <linux-kernel@vger.kernel.org>
Cc: David Woodhouse <dwmw2@infradead.org>,
	Miroslav Lichvar <mlichvar@redhat.com>,
	John Stultz <jstultz@google.com>, Stephen Boyd <sboyd@kernel.org>,
	Anna-Maria Behnsen <anna-maria@linutronix.de>,
	Frederic Weisbecker <frederic@kernel.org>,
	thomas.weissschuh@linutronix.de,
	Arthur Kiyanovski <akiyano@amazon.com>,
	Richard Cochran <richardcochran@gmail.com>,
	netdev@vger.kernel.org, Rodolfo Giometti <giometti@enneenne.com>,
	Vincent Donnefort <vdonnefort@google.com>,
	Marc Zyngier <maz@kernel.org>,
	Oliver Upton <oliver.upton@linux.dev>,
	kvmarm@lists.linux.dev, Oliver Upton <oupton@kernel.org>,
	Takashi Iwai <tiwai@suse.com>,
	Miri Korenblit <miriam.rachel.korenblit@intel.com>,
	Johannes Berg <johannes.berg@intel.com>,
	Jacob Keller <jacob.e.keller@intel.com>,
	Tony Nguyen <anthony.l.nguyen@intel.com>,
	Saeed Mahameed <saeedm@nvidia.com>,
	Peter Hilber <peter.hilber@oss.qualcomm.com>,
	"Michael S. Tsirkin" <mst@redhat.com>,
	virtualization@lists.linux.dev, linux-wireless@vger.kernel.org,
	linux-sound@vger.kernel.org
Subject: [patch 07/24] ptp: ptp_vmclock: Convert to ktime_get_snapshot_id()
Date: Tue, 26 May 2026 19:14:03 +0200	[thread overview]
Message-ID: <20260526171223.223860692@kernel.org> (raw)
In-Reply-To: 20260526165826.392227559@kernel.org

ktime_get_snapshot() is replaced by ktime_get_snapshot_id() which allows to
request a particular CLOCK ID to be captured along with the clocksource
counter.

Convert vmclock over and use the new system_time_snapshot::sys field, which
holds the system timestamp selected by the CLOCK ID argument.

No functional change intended.

Signed-off-by: Thomas Gleixner <tglx@kernel.org>
Cc: Richard Cochran <richardcochran@gmail.com>
Cc: netdev@vger.kernel.org
---
 drivers/ptp/ptp_vmclock.c |    8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

--- a/drivers/ptp/ptp_vmclock.c
+++ b/drivers/ptp/ptp_vmclock.c
@@ -132,7 +132,7 @@ static int vmclock_get_crosststamp(struc
 		 * will be derived from the *same* counter value.
 		 *
 		 * If the system isn't using the same counter, then the value
 		 * from ktime_get_snapshot() will still be used as pre_ts, and
 		 * ptp_read_system_postts() is called to populate postts after
 		 * calling get_cycles().
 		 *
@@ -140,7 +140,7 @@ static int vmclock_get_crosststamp(struc
 		 * the seq_count loop.
 		 */
 		if (sts) {
-			ktime_get_snapshot(&systime_snapshot);
+			ktime_get_snapshot_id(&systime_snapshot, CLOCK_REALTIME);
 			if (systime_snapshot.cs_id == st->cs_id) {
 				cycle = systime_snapshot.cycles;
 			} else {
@@ -181,7 +181,7 @@ static int vmclock_get_crosststamp(struc
 	}
 
 	if (sts) {
-		sts->pre_ts = ktime_to_timespec64(systime_snapshot.real);
+		sts->pre_ts = ktime_to_timespec64(systime_snapshot.sys);
 		if (systime_snapshot.cs_id == st->cs_id)
 			sts->post_ts = sts->pre_ts;
 	}
@@ -272,7 +272,7 @@ static int ptp_vmclock_getcrosststamp(st
 	if (ret == -ENODEV) {
 		struct system_time_snapshot systime_snapshot;
 
-		ktime_get_snapshot(&systime_snapshot);
+		ktime_get_snapshot_id(&systime_snapshot, CLOCK_REALTIME);
 
 		if (systime_snapshot.cs_id == CSID_X86_TSC ||
 		    systime_snapshot.cs_id == CSID_X86_KVM_CLK) {
@@ -132,7 +132,7 @@ static int vmclock_get_crosststamp(struc
 		 *
 		 * If the system isn't using the same counter, then the value
-		 * from ktime_get_snapshot() will still be used as pre_ts, and
+		 * from ktime_get_snapshot_id() will still be used as pre_ts, and
 		 * ptp_read_system_postts() is called to populate postts after
 		 * calling get_cycles().


  parent reply	other threads:[~2026-05-26 17:14 UTC|newest]

Thread overview: 31+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2026-05-26 17:13 [patch 00/24] timekeeping/ptp: Expand snapshot functionality Thomas Gleixner
2026-05-26 17:13 ` [patch 01/24] timekeeping: Provide ktime_get_snapshot_id() Thomas Gleixner
2026-05-26 21:41   ` Jacob Keller
2026-05-26 17:13 ` [patch 02/24] timekeeping: Use system_time_snapshot::sys instead of ::real Thomas Gleixner
2026-05-26 17:13 ` [patch 03/24] pps: generators: Use ktime_get_real_ts64() instead of ktime_get_snapshot() Thomas Gleixner
2026-05-26 17:13 ` [patch 04/24] pps: Convert to ktime_get_snapshot_id() Thomas Gleixner
2026-05-26 17:13 ` [patch 05/24] KVM: arm64: Use ktime_get_snapshot_id() to retrieve CLOCK_BOOTTIME Thomas Gleixner
2026-05-26 17:13 ` [patch 06/24] KVM: arm64: Use ktime_get_snapshot_id() to snapshot CLOCK_REALTIME Thomas Gleixner
2026-05-26 17:14 ` Thomas Gleixner [this message]
2026-05-26 17:14 ` [patch 08/24] timekeeping: Remove system_time_snapshot::real/boot Thomas Gleixner
2026-05-26 21:49   ` Jacob Keller
2026-05-26 21:52     ` Jacob Keller
2026-05-26 17:14 ` [patch 09/24] timekeeping: Add CLOCK_AUX support for ktime_get_snapshot_id() Thomas Gleixner
2026-05-26 17:14 ` [patch 10/24] timekeeping: Add system_counterval_t to struct system_device_crosststamp Thomas Gleixner
2026-05-26 17:14 ` [patch 11/24] timekeeping: Add CLOCK ID to system_device_crosststamp Thomas Gleixner
2026-05-26 17:14 ` [patch 12/24] wifi: iwlwifi: Adopt PTP cross timestamps to core changes Thomas Gleixner
2026-05-26 17:14 ` [patch 13/24] ice/ptp: Use provided clock ID for history snapshot Thomas Gleixner
2026-05-26 21:51   ` Jacob Keller
2026-05-26 17:14 ` [patch 14/24] igc: " Thomas Gleixner
2026-05-26 21:51   ` Jacob Keller
2026-05-26 17:14 ` [patch 15/24] net/mlx5: " Thomas Gleixner
2026-05-26 17:14 ` [patch 16/24] virtio_rtc: " Thomas Gleixner
2026-05-26 17:14 ` [patch 17/24] timekeeping: Remove ktime_get_snapshot() Thomas Gleixner
2026-05-26 17:14 ` [patch 18/24] timekeeping: Prepare for cross timestamps on arbitrary clock IDs Thomas Gleixner
2026-05-26 17:15 ` [patch 19/24] ptp: Use system_device_crosststamp::sys_systime Thomas Gleixner
2026-05-26 17:15 ` [patch 20/24] wifi: iwlwifi: " Thomas Gleixner
2026-05-26 17:15 ` [patch 21/24] ALSA: hda/common: " Thomas Gleixner
2026-05-26 17:15 ` [patch 22/24] timekeeping: Remove system_device_crosststamp::sys_realtime Thomas Gleixner
2026-05-26 17:15 ` [patch 23/24] timekeeping: Add support for AUX clock cross timestamping Thomas Gleixner
2026-05-26 17:15 ` [patch 24/24] ptp: Switch to ktime_get_snapshot_id() for pre/post timestamps Thomas Gleixner
2026-05-26 21:56 ` [patch 00/24] timekeeping/ptp: Expand snapshot functionality Jacob Keller

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20260526171223.223860692@kernel.org \
    --to=tglx@kernel.org \
    --cc=akiyano@amazon.com \
    --cc=anna-maria@linutronix.de \
    --cc=anthony.l.nguyen@intel.com \
    --cc=dwmw2@infradead.org \
    --cc=frederic@kernel.org \
    --cc=giometti@enneenne.com \
    --cc=jacob.e.keller@intel.com \
    --cc=johannes.berg@intel.com \
    --cc=jstultz@google.com \
    --cc=kvmarm@lists.linux.dev \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-sound@vger.kernel.org \
    --cc=linux-wireless@vger.kernel.org \
    --cc=maz@kernel.org \
    --cc=miriam.rachel.korenblit@intel.com \
    --cc=mlichvar@redhat.com \
    --cc=mst@redhat.com \
    --cc=netdev@vger.kernel.org \
    --cc=oliver.upton@linux.dev \
    --cc=oupton@kernel.org \
    --cc=peter.hilber@oss.qualcomm.com \
    --cc=richardcochran@gmail.com \
    --cc=saeedm@nvidia.com \
    --cc=sboyd@kernel.org \
    --cc=thomas.weissschuh@linutronix.de \
    --cc=tiwai@suse.com \
    --cc=vdonnefort@google.com \
    --cc=virtualization@lists.linux.dev \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox